@@ -31,8 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-$juri = JURI::getInstance();
-$sef = JRoute::_('index.php?option='.$this->option.'&task=details&id='.$this->event->id);
+$juri =& JURI::getInstance();
+$sef = JRoute::_('index.php?option='.$this->option.'&task=details&id='.$this->row->id);
 if (substr($sef,0,1) == '/') {
 	$sef = substr($sef,1,strlen($sef));
 }
